@@ -1,10 +1,16 @@
 import logging
+from typing import Any
 
 from twisted.internet.defer import inlineCallbacks
+from txhttputil.site.FileUnderlayResource import FileUnderlayResource
+from vortex.handler.TupleActionProcessorProxy import TupleActionProcessorProxy
+from vortex.handler.TupleDataObservableProxyHandler import (
+    TupleDataObservableProxyHandler,
+)
+from vortex.handler.TupleDataObserverClient import TupleDataObserverClient
 
-from peek_plugin_base.PeekVortexUtil import peekServerName
-from peek_plugin_base.client.PluginClientEntryHookABC import PluginClientEntryHookABC
-from peek_core_docdb._private.PluginNames import docDbFilt, docDbActionProcessorName
+from peek_core_docdb._private.PluginNames import docDbActionProcessorName
+from peek_core_docdb._private.PluginNames import docDbFilt
 from peek_core_docdb._private.PluginNames import docDbObservableName
 from peek_core_docdb._private.client.TupleDataObservable import (
     makeClientTupleDataObservableHandler,
@@ -18,28 +24,52 @@ from peek_core_docdb._private.client.handlers.DocumentCacheHandler import (
 from peek_core_docdb._private.storage.DeclarativeBase import loadStorageTuples
 from peek_core_docdb._private.tuples import loadPrivateTuples
 from peek_core_docdb.tuples import loadPublicTuples
-from vortex.handler.TupleActionProcessorProxy import TupleActionProcessorProxy
-from vortex.handler.TupleDataObservableProxyHandler import (
-    TupleDataObservableProxyHandler,
+from peek_plugin_base.PeekVortexUtil import peekServerName
+from peek_plugin_base.client.PluginClientEntryHookABC import (
+    PluginClientEntryHookABC,
 )
-from vortex.handler.TupleDataObserverClient import TupleDataObserverClient
 
 logger = logging.getLogger(__name__)
 
 
 class ClientEntryHook(PluginClientEntryHookABC):
     def __init__(self, *args, **kwargs):
-        """" Constructor """
+        """ " Constructor"""
         # Call the base classes constructor
         PluginClientEntryHookABC.__init__(self, *args, **kwargs)
 
         #: Loaded Objects, This is a list of all objects created when we start
         self._loadedObjects = []
 
+    @classmethod
+    def setupStaticWebResources(cls, platformApi: Any):
+        from peek_plugin_base.client.PeekClientPlatformHookABC import (
+            PeekClientPlatformHookABC,
+        )
+
+        assert isinstance(
+            platformApi, PeekClientPlatformHookABC
+        ), "We received the wrong platform API"
+
+        from peek_abstract_chunked_index.private.client.controller.ACICacheControllerABC import (
+            ACICacheControllerABC,
+        )
+
+        relativeDir = ACICacheControllerABC.appDownloadPluginDirRelativeDir()
+        dirPath = platformApi.fileStorageDirectory / relativeDir
+        dirPath.mkdir(exist_ok=True, parents=True)
+
+        resource = FileUnderlayResource()
+        resource.addFileSystemRoot(dirPath)
+
+        platformApi.addFieldResource(relativeDir.encode(), resource)
+        platformApi.addOfficeResource(relativeDir.encode(), resource)
+
     def load(self) -> None:
         """Load
 
-        This will be called when the plugin is loaded, just after the db is migrated.
+        This will be called when the plugin is loaded,
+         just after the db is migrated.
         Place any custom initialiastion steps here.
 
         """
@@ -94,14 +124,17 @@ class ClientEntryHook(PluginClientEntryHookABC):
         # ----------------
         # Document Cache Controller
 
-        documentCacheController = DocumentCacheController(self.platform.serviceId)
+        documentCacheController = DocumentCacheController(
+            self.platform.serviceId, self.platform.fileStorageDirectory
+        )
         self._loadedObjects.append(documentCacheController)
 
         # ----------------
         # Document Cache Handler
 
         documentHandler = DocumentCacheHandler(
-            cacheController=documentCacheController, clientId=self.platform.serviceId
+            cacheController=documentCacheController,
+            clientId=self.platform.serviceId,
         )
         self._loadedObjects.append(documentHandler)
 
@@ -117,6 +150,7 @@ class ClientEntryHook(PluginClientEntryHookABC):
 
         # ----------------
         # Start the compiler controllers
+        yield documentHandler.start()
         yield documentCacheController.start()
 
         logger.debug("Started")
