@@ -6,6 +6,9 @@ from vortex.Tuple import Tuple
 from peek_abstract_chunked_index.private.server.client_handlers.ACIChunkLoadRpcABC import (
     ACIChunkLoadRpcABC,
 )
+from peek_core_docdb._private.tuples.DocumentUpdateDateTuple import (
+    DocumentUpdateDateTuple,
+)
 from peek_plugin_base.PeekVortexUtil import peekServerName, peekBackendNames
 from peek_core_docdb._private.PluginNames import docDbFilt
 from peek_core_docdb._private.storage.DocDbEncodedChunk import DocDbEncodedChunk
@@ -25,6 +28,7 @@ class ClientChunkLoadRpc(ACIChunkLoadRpcABC):
         """
 
         yield self.loadDocumentChunks.start(funcSelf=self)
+        yield self.loadDocumentIndexDelta.start(funcSelf=self)
         logger.debug("RPCs started")
 
     # -------------
@@ -35,12 +39,20 @@ class ClientChunkLoadRpc(ACIChunkLoadRpcABC):
         additionalFilt=docDbFilt,
         deferToThread=True,
     )
-    def loadDocumentChunks(self, offset: int, count: int) -> str:
-        """Update Page Loader Status
+    def loadDocumentIndexDelta(self, indexEncodedPayload: bytes) -> bytes:
+        return self.ckiChunkIndexDeltaBlocking(
+            indexEncodedPayload, DocDbEncodedChunk, DocumentUpdateDateTuple
+        )
 
-        Tell the server of the latest status of the loader
-
-        """
+    # -------------
+    @vortexRPC(
+        peekServerName,
+        acceptOnlyFromVortex=peekBackendNames,
+        timeoutSeconds=60,
+        additionalFilt=docDbFilt,
+        deferToThread=True,
+    )
+    def loadDocumentChunks(self, chunkKeys: list[str]) -> list[Tuple]:
         return self.ckiInitialLoadChunksPayloadBlocking(
-            offset, count, DocDbEncodedChunk
+            chunkKeys, DocDbEncodedChunk
         )
